@@ -14,5 +14,8 @@ from .initializers import get_initializer
 
 from .wrappers import Concat
 
+from .data import BaseDataSet, Feature, Featurizer
+
 import params_flow.utils as utils
 import params_flow.optimizers as optimizers
+import params_flow.data as data
